@@ -659,6 +659,11 @@ background_image_changed (GtkWidget       *entry,
   char *text;
   
   text = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (entry));
+
+  if (text == NULL)
+    {
+      return;
+    }
   
   terminal_profile_set_background_image_file (profile, text);
 
@@ -1190,22 +1195,31 @@ terminal_profile_edit (TerminalProfile *profile,
       i = 0;
       while (i < TERMINAL_PALETTE_SIZE)
         {
-          char *s = g_strdup_printf ("palette-colorpicker-%d", i+1);
-          
-          w = glade_xml_get_widget (xml, s);
-          g_assert (w);
-          
-          g_object_set_data (G_OBJECT (w),
-                             "palette-entry-index",
-                             GINT_TO_POINTER (i));
+	  gchar *t;
+	  gchar *s = g_strdup_printf ("palette-colorpicker-%d", i+1);
 
-          g_signal_connect (G_OBJECT (w), "color_set",
-                            G_CALLBACK (palette_color_set),
-                            profile);
-          
-          g_free (s);
+	  w = glade_xml_get_widget (xml, s);
+	  g_assert (w);
 
-          ++i;
+	  t = g_strdup_printf (_("Choose Palette Color %d"), i+1);
+	  gtk_color_button_set_title (GTK_COLOR_BUTTON (w), t);
+	  g_free (t);
+
+	  t = g_strdup_printf (_("Palette entry %d"), i+1);
+	  gtk_tooltips_set_tip (gtk_tooltips_data_get(w)->tooltips, w, t, NULL);
+	  g_free (t);
+
+	  g_object_set_data (G_OBJECT (w),
+			     "palette-entry-index",
+			     GINT_TO_POINTER (i));
+
+	  g_signal_connect (G_OBJECT (w), "color_set",
+			    G_CALLBACK (palette_color_set),
+			    profile);
+
+	  g_free (s);
+
+	  ++i;
         }
 
       profile_editor_update_palette (editor, profile);
